cutPaper method

void cutPaper({
  1. CutPaper paperCut = const CutPaper.functionB(n: 0),
})

Cut paper and optionally specify the CuttingShape and the amount of paper feed.

  • Use PaperCutting.functionA if you want to simply cut the paper.
  • Use PaperCutting.functionB if you want to feeds the paper before cut.

Notes:

References:

Implementation

void cutPaper({
  CutPaper paperCut = const CutPaper.functionB(n: 0),
}) {
  _commands.add(paperCut);
}